=== modified file 'bzrlib/commands.py'
--- bzrlib/commands.py	2009-12-21 19:33:31 +0000
+++ bzrlib/commands.py	2009-12-22 19:13:59 +0000
@@ -870,8 +870,8 @@
 
 def shlex_split_unicode(unsplit):
     if sys.platform == "win32":
-        import bzrlib.win32utils as win32utils
-        return win32utils.command_line_to_argv(unsplit)
+        from bzrlib.win32utils import command_line_to_argv
+        return command_line_to_argv(unsplit, wildcard_expansion=False)
     else:
         import shlex
         return [u.decode('utf-8') for u in shlex.split(unsplit.encode('utf-8'))]

=== modified file 'bzrlib/win32utils.py'
--- bzrlib/win32utils.py	2009-12-21 19:33:31 +0000
+++ bzrlib/win32utils.py	2009-12-22 19:13:59 +0000
@@ -614,20 +614,25 @@
         return quoted, token
 
 
-def command_line_to_argv(command_line):
-    """Convert a Unicode command line into a set of argv arguments.
-
-    This does wildcard expansion, etc. It is intended to make wildcards act
-    closer to how they work in posix shells, versus how they work by default on
-    Windows.
+def command_line_to_argv(command_line, wildcard_expansion=True):
+    """Convert a Unicode command line into a list of argv arguments.
+
+    This optionally does wildcard expansion, etc. It is intended to make
+    wildcards act closer to how they work in posix shells, versus how they
+    work by default on Windows. Quoted arguments are left untouched.
+
+    :param command_line: The unicode string to split into an arg list.
+    :param wildcard_expansion: Whether wildcard expansion should be applied to
+                               each argument. True by default.
+    :return: A list of unicode strings.
     """
     s = UnicodeShlex(command_line)
-    # Now that we've split the content, expand globs
+    # Now that we've split the content, expand globs if necessary
     # TODO: Use 'globbing' instead of 'glob.glob', this gives us stuff like
     #       '**/' style globs
     args = []
     for is_quoted, arg in s:
-        if is_quoted or not glob.has_magic(arg):
+        if is_quoted or not glob.has_magic(arg) or not wildcard_expansion:
             args.append(arg)
         else:
             args.extend(glob_one(arg))

